/**
 * 多媒体管理器
 */
var MediaManager = {
	/**
	 *  七牛空间域名
	 */
	QINIU_URL: QINIU_PREFIX,
	/**
	 * 最大上传文件数
	 */
	MAX_FILE_NUM: 20,
	/**
	 * 七牛上传器
	 */
	qiniuUploader: null,
	/**
	 * 上传控件
	 */
	uploadCtrl: document.getElementById("txtUpload"),
	/*
	 * 附件列表
	 */
	attachmentList: document.getElementById('attachmemtList'),
	/**
	 * 已上传图片
	 */
	arrUploadedImg: [],
	/**
	 * 初始化
	 */
	init: function() {
		//上传图标点击事件监听
		document.getElementById("btnAdd").addEventListener('tap', function() {
			MediaManager.upload();
		});

		//上传控件内容变化事件监听
		document.getElementById("txtUpload").addEventListener('change', function(event) {
			document.getElementById('container').querySelector('input[type=file]').setAttribute('accept', 'image/*,video/*,audio/*');
			MediaManager.uploadFile();
		});

		MediaManager.initQiniuToken();
	},
	/**
	 * 初始化七牛令牌
	 */
	initQiniuToken: function() {
		var token_url = API_URL + "/Complain/GetQiniuToken";
		$ajax(token_url, {
			success: function(data) {
				// var token = eval("(" + data + ")");
				MediaManager.initQiniu(data.uptoken);
			}
		});
	},
	/**
	 * 初始化七牛
	 * 
	 * @param {Object} qiniuToken 七牛令牌
	 */
	initQiniu: function(qiniuToken) {
		MediaManager.qiniuUploader = Qiniu.uploader({
			runtimes: 'html5',
			browse_button: 'btnUpload',
			container: 'container',
			drop_element: 'container',
			max_file_size: '10mb',
			dragdrop: false,
			chunk_size: '4mb',
			uptoken: qiniuToken,
			multi_selection: false,
			unique_names: true, // 默认 false，key为文件名。若开启该选项，SDK为自动生成上传成功后的key（文件名）。
			domain: MediaManager.QINIU_URL,
			auto_start: true,
			init: {}
		});
		MediaManager.qiniuUploader.bind('FilesAdded', function(up, files) {
			var count = MediaManager.attachmentList.childElementCount;
			MediaManager.attachmentList.childNodes[count - 2].id = files[0].id;
			MediaManager.uploadCtrl.value = '';
			mui.toast('正在上传附件...请稍等');
		});
		MediaManager.qiniuUploader.bind('FileUploaded', function(up, file, info) {
			var imgUrl = MediaManager.QINIU_URL + file.target_name;
			var saveImgUrl = file.target_name;
			var thumbUrl = imgUrl + "?imageView2/1/w/60/h/60";
			var count = MediaManager.attachmentList.childElementCount;
			var node = MediaManager.attachmentList.childNodes[count - 1];
			node.querySelector('img').setAttribute('src', thumbUrl);
			node.querySelector('img').setAttribute('uri', imgUrl);
			MediaManager.arrUploadedImg.push(saveImgUrl);
			mui.toast('附件上传完毕！请继续！');
		});
	},
	/**
	 * 上传
	 */
	upload: function() {
		if(MediaManager.attachmentList.childElementCount > MediaManager.MAX_FILE_NUM) {
			return mui.toast('附件最多只能有' + MediaManager.MAX_FILE_NUM + '个！');
		}
		MediaManager.uploadCtrl.click();
		
	},
	/**
	 * 上传文件
	 * 
	 */
	uploadFile: function() {
		var fileName = MediaManager.uploadCtrl.value.toLowerCase();
		if(fileName) {
			if(MediaManager.attachmentList.childElementCount > MediaManager.MAX_FILE_NUM) {
				return mui.toast('附件最多只能有' + MediaManager.MAX_FILE_NUM + '个！');
			}
			var attachment = MediaManager.uploadCtrl.files[0];
			var li = document.createElement('li');
			var imageReg = new RegExp("(.jpg|.png|.bmp|.jpeg|.webp|.gif)$", 'i');
			if(imageReg.test(fileName)) {
				var img = document.createElement('img');
				var imgUrl = window.URL.createObjectURL(attachment);
				img.src = "";
				img.setAttribute('onclick', 'MediaManager.show(this.parentNode);');

				var imgWrapper = document.createElement('div');
				imgWrapper.classList.add('img-wrapper');
				imgWrapper.appendChild(img);
				li.appendChild(imgWrapper);
				//添加删除按钮
				var span = document.createElement("span");
				span.className = "del";
				span.setAttribute("uri", imgUrl);
				span.innerHTML = "×";
				span.addEventListener("click", function(that) {
					mui.confirm("真的要删除吗？", "温馨提示", ['是', '否'], function(e) {
						if(e.index == 0) {
							MediaManager.removeImg(that.target.parentElement.id);
						}
					});
					return false;
				});
				li.appendChild(span);
			} else return mui.toast(fileName + ':类型不支持或文件名太长');
			MediaManager.attachmentList.insertBefore(li, MediaManager.attachmentList.lastElementChild);
			MediaManager.qiniuUploader.addFile(MediaManager.uploadCtrl.files[0]);
		}
	},
	/**
	 * 显示多媒体
	 * 
	 * @param {Object} li 
	 */
	show: function(img) {
		MUIPopover.autoPopover({
			domSource: img.parentElement
		});
	},
	/**
	 * Clear Img
	 * 
	 * @param {Object} url
	 */
	removeImg: function(url) {
		var newArrImg = [];
		var idx = 0;
		for(var i = 0; i < MediaManager.arrUploadedImg.length; i++) {
			if(MediaManager.arrUploadedImg[i].indexOf(url) <= 0) {
				newArrImg.push(MediaManager.arrUploadedImg[i]);
			} else {
				idx = i;
			}
		}
		MediaManager.arrUploadedImg = [];
		MediaManager.arrUploadedImg = newArrImg;
		//删除图片
		var liNode = document.getElementById('attachmemtList').getElementsByTagName("li");
		MediaManager.attachmentList.removeChild(liNode[idx]);
	},
	/**
	 * 删除所有图片
	 * 
	 * @param {Object} url
	 */
	removeAll: function() {
		for(var i = 0; i < MediaManager.arrUploadedImg.length; i++) {
			MediaManager.removeImg(MediaManager.arrUploadedImg[i]);
		}
	}
};